@@ -1,7 +1,14 @@
 # Configure the needed tempest options
 function configure_barbican_tempest() {
     iniset $TEMPEST_CONFIG service_available barbican True
-    iniset $TEMPEST_CONFIG auth tempest_roles creator
+    roles="$(iniget $TEMPEST_CONFIG auth tempest_roles)"
+    if [[ -z $roles ]]; then
+        roles="creator"
+    else
+        roles="$roles,creator"
+    fi
+    iniset $TEMPEST_CONFIG auth tempest_roles $roles
+    iniset $TEMPEST_CONFIG service_available barbican True
 }
 
 # check for service enabled
@@ -13,7 +20,7 @@ if is_service_enabled barbican; then
 
     if [[ "$1" == "stack" && "$2" == "install" ]]; then
         echo_summary "Installing Barbican"
-        install_barbican
+        stack_install_service barbican
         install_barbicanclient
         if is_service_enabled barbican-pykmip; then
             echo_summary "Installing PyKMIP"
@@ -23,6 +30,10 @@ if is_service_enabled barbican; then
             echo_summary "Installing Dogtag"
             install_dogtag_components
         fi
+        if is_service_enabled barbican-vault; then
+            echo_summary "Installing Vault"
+            install_vault
+        fi
     elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
         echo_summary "Configuring Barbican"
         configure_barbican
@@ -34,6 +45,10 @@ if is_service_enabled barbican; then
             echo_summary "Configuring Dogtag plugin"
             configure_dogtag_plugin
         fi
+        if is_service_enabled barbican-vault; then
+            echo_summary "Configuring Vault plugin"
+            configure_vault_plugin
+        fi
         configure_barbicanclient
 
         # Configure Cinder, Nova and Glance to use Barbican
@@ -73,7 +88,7 @@ function configure_core_services {
     fi
 
     if is_service_enabled c-vol; then
-        iniset $CINDER_CONF key_manager backend 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager'
+        iniset $CINDER_CONF key_manager backend 'barbican'
     fi
 
     if is_service_enabled g-api; then
