@@ -78,7 +78,7 @@ pygments_style = 'sphinx'
 # html_theme_path = ["."]
 # html_theme = '_theme'
 html_theme = 'openstackdocs'
-# html_static_path = ['static']
+html_static_path = ['_static']
 html_theme_options = {}
 
 # Output file base name for HTML help builder.
